from prompt_searcher.core.interfaces.agent import Agent
from anthropic import Anthropic

class AnthropicAgent(Agent):
    def __init__(self, model: str, api_key: str = None, **kwargs):
        self.model = model
        self.client = Anthropic(api_key=api_key, **kwargs)

    def generate_response(self, system_message: str, user_message: str, max_tokens: int = 1024) -> str:
        """
        Generate a response from the Anthropic model.

        Args:
            system_message (str): The system message providing context to the model.
            user_message (str): The user message for which the model will generate a response.

        Returns:
            str: The response generated by the model.
        """
        completion = self.client.messages.create(
            model=self.model,
            max_tokens=max_tokens,
            messages=[
                {"role": "system", "content": system_message},
                {"role": "user", "content": user_message}
            ]
        )
        return completion.content[0].text

# Example usage:
# agent = AnthropicAgent(model="claude-3-opus-20240229", api_key=os.environ.get("ANTHROPIC_API_KEY", "<your Anthropic API key if not set as an env var>"))
# response = agent.generate_response("System message", "User message")
# print(response)
