from prompt_searcher.core.interfaces.agent import Agent
from groq import Groq

class GroqAgent(Agent):
    def __init__(self, model: str, api_key: str, **kwargs):
        self.model = model
        self.client = Groq(api_key=api_key, **kwargs)

    def generate_response(self, system_message: str, user_message: str) -> str:
        """
        Generate a response from the Groq model.

        Args:
            system_message (str): The system message providing context to the model.
            user_message (str): The user message for which the model will generate a response.

        Returns:
            str: The response generated by the model.
        """
        messages = [
            {"role": "system", "content": system_message},
            {"role": "user", "content": user_message}
        ]

        completion = self.client.chat.completions.create(
            model=self.model,
            messages=messages
        )
        return completion.choices[0].message.content

# Example usage:
# agent = GroqAgent(model="groq-v1", api_key=os.environ.get("GROQ_API_KEY", "<your Groq API key if not set as an env var>"))
# response = agent.generate_response("System message", "User message")
# print(response)
